@@ -1,3 +1,5 @@
+# coding: utf-8
+
 # django imports
 from django.contrib.auth.models import User
 from django.contrib.sessions.backends.file import SessionStore
@@ -6,6 +8,7 @@ from django.test import TestCase
 from django.utils import simplejson
 
 # lfs imports
+from lfs.caching.utils import lfs_get_object_or_404
 import lfs.cart.utils
 from lfs.cart.models import Cart
 from lfs.cart.models import CartItem
@@ -15,6 +18,7 @@ from lfs.cart.views import refresh_cart
 from lfs.catalog.models import DeliveryTime
 from lfs.catalog.models import Product
 from lfs.catalog.settings import DELIVERY_TIME_UNIT_DAYS
+from lfs.core.models import Shop
 from lfs.tests.utils import RequestFactory
 from lfs.tests.utils import create_request
 from lfs.tax.models import Tax
@@ -23,12 +27,18 @@ from lfs.voucher.models import VoucherGroup
 from lfs.voucher.settings import ABSOLUTE
 from lfs.voucher.settings import PERCENTAGE
 
+
 class CartModelsTestCase(TestCase):
     """
     """
+    fixtures = ['lfs_shop.xml']
+
     def setUp(self):
         """
         """
+        self.request = RequestFactory().get("/")
+        self.request.session = SessionStore()
+
         self.tax = Tax.objects.create(rate=19.0)
 
         self.p1 = Product.objects.create(name="Product 1", slug="product-1", price=10.0, tax=self.tax)
@@ -41,33 +51,34 @@ class CartModelsTestCase(TestCase):
     def test_get_price(self):
         """
         """
-        price_net = self.cart.get_price_net()
+        price_net = self.cart.get_price_net(self.request)
         self.assertEqual("%.2f" % price_net, "%.2f" % 92.44)
 
     def test_get_gross(self):
         """
         """
-        price_gross = self.cart.get_price_gross()
+        price_gross = self.cart.get_price_gross(self.request)
         self.assertEqual(price_gross, 110.0)
 
     def test_tax(self):
         """
         """
-        tax = self.cart.get_tax()
+        tax = self.cart.get_tax(self.request)
         self.assertEqual("%.2f" % tax, "%.2f" % 17.56)
 
     def test_get_amount_of_items(self):
         """
         """
-        amount = self.cart.amount_of_items
+        amount = self.cart.get_amount_of_items()
         self.assertEqual(2, 2)
 
     def test_get_items(self):
         """
         """
-        items = self.cart.items()
+        items = self.cart.get_items()
         self.assertEqual(len(items), 2)
 
+
 class CartItemTestCase(TestCase):
     """
     """
@@ -86,9 +97,12 @@ class CartItemTestCase(TestCase):
         result = self.item.get_properties()
         self.assertEqual(result, [])
 
+
 class AddToCartTestCase(TestCase):
     """Test case for add_to_cart view.
     """
+    fixtures = ['lfs_shop.xml']
+
     def setUp(self):
         """
         """
@@ -103,7 +117,7 @@ class AddToCartTestCase(TestCase):
         """Try to add product to the cart which is not active.
         """
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -117,7 +131,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -134,7 +148,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 2})
         request.session = self.session
         request.user = self.user
 
@@ -147,7 +161,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
         # ... or LFS doesn't manage stock amount
         self.p1.manage_stock_amount = False
@@ -155,7 +169,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
     def test_add_to_cart_stock_1(self):
         """Try to add product two times to cart if only one is in stock.
@@ -167,7 +181,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 2})
         request.session = self.session
         request.user = self.user
 
@@ -180,7 +194,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
         # ... or LFS doesn't manage stock amount
         self.p1.manage_stock_amount = False
@@ -188,7 +202,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
     def test_add_to_cart_stock_2(self):
         """Try to add product three times to cart if only two is in stock.
@@ -200,7 +214,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 3})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 3})
         request.session = self.session
         request.user = self.user
 
@@ -213,7 +227,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
         # ... or LFS doesn't manage stock amount
         self.p1.manage_stock_amount = False
@@ -221,7 +235,7 @@ class AddToCartTestCase(TestCase):
         self.p1.save()
 
         result = add_to_cart(request)
-        self.failIf(result.cookies.has_key("message"))
+        self.failIf("message" in result.cookies)
 
 
 class RefreshCartTestCase(TestCase):
@@ -241,7 +255,7 @@ class RefreshCartTestCase(TestCase):
         """Don't manage stock amount.
         """
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -249,15 +263,15 @@ class RefreshCartTestCase(TestCase):
         result = add_to_cart(request)
 
         cart = lfs.cart.utils.get_cart(request)
-        self.assertEqual(cart.amount_of_items, 1.0)
+        self.assertEqual(cart.get_amount_of_items(), 1.0)
 
         # Refresh item amount
-        request = rf.post("/", {"product_id" : self.p1.id, "amount-cart-item_%s" % cart.items()[0].id : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "amount-cart-item_%s" % cart.get_items()[0].id: 2})
         request.session = self.session
         request.user = self.user
 
         refresh_cart(request)
-        self.assertEqual(cart.amount_of_items, 2.0)
+        self.assertEqual(cart.get_amount_of_items(), 2.0)
 
     def test_amount_2(self):
         """Manage stock amount; refresh to 2 only 1 products there.
@@ -267,7 +281,7 @@ class RefreshCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -275,10 +289,10 @@ class RefreshCartTestCase(TestCase):
         result = add_to_cart(request)
 
         cart = lfs.cart.utils.get_cart(request)
-        self.assertEqual(cart.amount_of_items, 1.0)
+        self.assertEqual(cart.get_amount_of_items(), 1.0)
 
         # Try to increase item to two, but there is only one in stock
-        request = rf.post("/", {"product_id" : self.p1.id, "amount-cart-item_%s" % cart.items()[0].id : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "amount-cart-item_%s" % cart.get_items()[0].id: 2})
         request.session = self.session
         request.user = self.user
 
@@ -287,7 +301,7 @@ class RefreshCartTestCase(TestCase):
         self.assertEqual(result.get("message"), "Sorry, but \'Product 1\' is only one time available.")
 
         # And the amount of the item is still 1.0
-        self.assertEqual(cart.amount_of_items, 1.0)
+        self.assertEqual(cart.get_amount_of_items(), 1.0)
 
         # If the product is ordered the customer can add it into cart again
         self.p1.order_time = self.dt
@@ -295,7 +309,7 @@ class RefreshCartTestCase(TestCase):
 
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "")
-        self.assertEqual(cart.amount_of_items, 2.0)
+        self.assertEqual(cart.get_amount_of_items(), 2.0)
 
         # Or if LFS not managing stock amount the product can be added to the cart
         self.p1.order_time = None
@@ -304,7 +318,7 @@ class RefreshCartTestCase(TestCase):
 
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "")
-        self.assertEqual(cart.amount_of_items, 2.0)
+        self.assertEqual(cart.get_amount_of_items(), 2.0)
 
     def test_amount_3(self):
         """Manage stock amount; refresh to 3 only 2 products there.
@@ -314,7 +328,7 @@ class RefreshCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -322,20 +336,20 @@ class RefreshCartTestCase(TestCase):
         result = add_to_cart(request)
 
         cart = lfs.cart.utils.get_cart(request)
-        self.assertEqual(cart.amount_of_items, 1.0)
+        self.assertEqual(cart.get_amount_of_items(), 1.0)
 
         # Try to increase item to two, but there is only one in stock
-        request = rf.post("/", {"product_id" : self.p1.id, "amount-cart-item_%s" % cart.items()[0].id : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "amount-cart-item_%s" % cart.get_items()[0].id: 2})
         request.session = self.session
         request.user = self.user
 
         # Refresh to amount of two is possible
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "")
-        self.assertEqual(cart.amount_of_items, 2.0)
+        self.assertEqual(cart.get_amount_of_items(), 2.0)
 
         # Try to increase item to 3, but there are only 2 in stock
-        request = rf.post("/", {"product_id" : self.p1.id, "amount-cart-item_%s" % cart.items()[0].id : 3})
+        request = rf.post("/", {"product_id": self.p1.id, "amount-cart-item_%s" % cart.get_items()[0].id: 3})
         request.session = self.session
         request.user = self.user
 
@@ -343,7 +357,7 @@ class RefreshCartTestCase(TestCase):
         self.assertEqual(result.get("message"), "Sorry, but \'Product 1\' is only 2.0 times available.")
 
         # And the amount of the item is still 2.0
-        self.assertEqual(cart.amount_of_items, 2.0)
+        self.assertEqual(cart.get_amount_of_items(), 2.0)
 
         # If the product is ordered the customer can add it into cart again
         self.p1.order_time = self.dt
@@ -351,7 +365,7 @@ class RefreshCartTestCase(TestCase):
 
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "")
-        self.assertEqual(cart.amount_of_items, 3.0)
+        self.assertEqual(cart.get_amount_of_items(), 3.0)
 
         # Or if LFS not managing stock amount the product can be added to the cart
         self.p1.order_time = None
@@ -360,7 +374,7 @@ class RefreshCartTestCase(TestCase):
 
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "")
-        self.assertEqual(cart.amount_of_items, 3.0)
+        self.assertEqual(cart.get_amount_of_items(), 3.0)
 
     def test_amount_4(self):
         """Manage stock amount; refresh to 2 but no product is there anymore.
@@ -370,7 +384,7 @@ class RefreshCartTestCase(TestCase):
         self.p1.save()
 
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 1})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 1})
         request.session = self.session
         request.user = self.user
 
@@ -378,20 +392,21 @@ class RefreshCartTestCase(TestCase):
         result = add_to_cart(request)
 
         cart = lfs.cart.utils.get_cart(request)
-        self.assertEqual(cart.amount_of_items, 1.0)
+        self.assertEqual(cart.get_amount_of_items(), 1.0)
 
         self.p1.stock_amount = 0
         self.p1.save()
 
         # Try to increase item to two, but there is no product in stock anymore
-        request = rf.post("/", {"product_id" : self.p1.id, "amount-cart-item_%s" % cart.items()[0].id : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "amount-cart-item_%s" % cart.get_items()[0].id: 2})
         request.session = self.session
         request.user = self.user
 
         # Refresh to amount of two is not possible
         result = simplejson.loads(refresh_cart(request).content)
         self.assertEqual(result.get("message"), "Sorry, but 'Product 1' is not available anymore.")
-        self.assertEqual(cart.amount_of_items, 0.0)
+        self.assertEqual(cart.get_amount_of_items(), 0.0)
+
 
 class AddedToCartTestCase(TestCase):
     """
@@ -412,34 +427,44 @@ class AddedToCartTestCase(TestCase):
         """Add a product without quantity to cart (implicit 1)
         """
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id})
+        request = rf.post("/", {"product_id": self.p1.id})
         request.session = self.session
         request.user = self.user
 
         # Added product_1 to cart
         add_to_cart(request)
         response = added_to_cart_items(request)
-        self.failIf(response.find("Total: 10,00 EUR") == -1)
+
+        # Check we are using german locale
+        shop = lfs_get_object_or_404(Shop, pk=1)
+        self.assertEqual(shop.default_locale, 'en_US.UTF-8')
+
+        # need to test for two versions of currency output (Mac and Ubuntu differ)
+        self.failIf(response.find(u"Total: $10.00") == -1)
 
         # Added product_1 to cart again
         add_to_cart(request)
         response = added_to_cart_items(request)
-        self.failIf(response.find("Total: 20,00 EUR") == -1)
+        self.failIf(response.find(u"Total: $20.00") == -1)
 
     def test_totals_2(self):
         """Add a product with explicit quantity to cart
         """
         rf = RequestFactory()
-        request = rf.post("/", {"product_id" : self.p1.id, "quantity" : 2})
+        request = rf.post("/", {"product_id": self.p1.id, "quantity": 2})
         request.session = self.session
         request.user = self.user
 
+        # Check we are using german locale
+        shop = lfs_get_object_or_404(Shop, pk=1)
+        self.assertEqual(shop.default_locale, 'en_US.UTF-8')
+
         # Added product_1 two times to cart
         add_to_cart(request)
         response = added_to_cart_items(request)
-        self.failIf(response.find("Total: 20,00 EUR") == -1)
+        self.failIf(response.find(u"Total: $20.00") == -1)
 
         # Added product_1 two times to cart again
         add_to_cart(request)
         response = added_to_cart_items(request)
-        self.failIf(response.find("Total: 40,00 EUR") == -1)
+        self.failIf(response.find(u"Total: $40.00") == -1)
