@@ -110,9 +110,9 @@ def cart_inline(request, template_name="lfs/cart/cart_inline.html"):
         cart_items.append({
             "obj": cart_item,
             "product": cart_item.product,
-            "product_price_net": cart_item.product.get_price_net(request),
-            "product_price_gross": cart_item.product.get_price_gross(request) * cart_item.amount,
-            "product_tax": cart_item.product.get_tax(request),
+            "product_price_net": cart_item.get_price_net(request),
+            "product_price_gross": cart_item.get_price_gross(request),
+            "product_tax": cart_item.get_tax(request),
         })
 
     return render_to_string(template_name, RequestContext(request, {
@@ -170,9 +170,9 @@ def added_to_cart_items(request, template_name="lfs/cart/added_to_cart_items.htm
         cart_items.append({
             "product": cart_item.product,
             "obj": cart_item,
-            "product_price_net": cart_item.product.get_price_net(request),
-            "product_tax": cart_item.product.get_tax(request),
-            "product_price_gross": cart_item.product.get_price_gross(request),
+            "product_price_net": cart_item.get_price_net(request),
+            "product_price_gross": cart_item.get_price_gross(request),
+            "product_tax": cart_item.get_tax(request),
         })
 
     return render_to_string(template_name, {
