@@ -111,16 +111,22 @@ def calculate_price(request, id):
                     property_price += po.price
 
     if product.for_sale:
-        for_sale_standard_price = product.get_standard_price(with_properties=False)
+        for_sale_standard_price = product.get_standard_price(request, with_properties=False)
         for_sale_standard_price += property_price
+
+        for_sale_price = product.get_for_sale_price(request, with_properties=False)
+        for_sale_price += property_price
     else:
         for_sale_standard_price = 0
-        price = product.get_price(request, with_properties=False)
-        price += property_price
+        for_sale_price = 0
+
+    price = product.get_price(request, with_properties=False)
+    price += property_price
 
     result = simplejson.dumps({
         "price": lfs_tags.currency(price),
         "for-sale-standard-price": lfs_tags.currency(for_sale_standard_price),
+        "for-sale-price": lfs_tags.currency(for_sale_price),
         "message": _("Price has been changed according to your selection."),
     }, cls=LazyEncoder)
 
