@@ -7,6 +7,7 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.template import RequestContext
 from django.template.loader import render_to_string
+from django.views.decorators.http import require_POST
 
 # lfs imports
 from lfs.catalog.models import Product
@@ -21,9 +22,11 @@ from lfs.catalog.settings import PROPERTY_VALUE_TYPE_FILTER
 from lfs.catalog.settings import PROPERTY_VALUE_TYPE_DISPLAY
 from lfs.core.signals import product_removed_property_group
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_properties(request, product_id, template_name="manage/product/properties.html"):
-    """
+    """Displays the UI for manage the properties for the product with passed
+    product_id.
     """
     product = get_object_or_404(Product, pk=product_id)
 
@@ -35,6 +38,7 @@ def manage_properties(request, product_id, template_name="manage/product/propert
     filterables = []
     displayables = []
 
+    # Configurable
     if not product.is_product_with_variants():
         for property_group in product.property_groups.all():
             properties = []
@@ -43,7 +47,7 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                 display_configurables = True
 
                 try:
-                    ppv = ProductPropertyValue.objects.get(property = property, product=product, type=PROPERTY_VALUE_TYPE_DEFAULT)
+                    ppv = ProductPropertyValue.objects.get(property=property, product=product, type=PROPERTY_VALUE_TYPE_DEFAULT)
                 except ProductPropertyValue.DoesNotExist:
                     ppv_id = None
                     ppv_value = ""
@@ -54,35 +58,35 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                 # Mark selected options
                 options = []
                 for option in property.options.all():
-
-                    if str(option.id) == ppv_id:
+                    if str(option.id) == ppv_value:
                         selected = True
                     else:
                         selected = False
 
                     options.append({
-                        "id"       : option.id,
-                        "name"     : option.name,
-                        "selected" : selected,
+                        "id": option.id,
+                        "name": option.name,
+                        "selected": selected,
                     })
 
                 properties.append({
-                    "id" : property.id,
-                    "name" : property.name,
-                    "title" : property.title,
-                    "type" : property.type,
-                    "options" : options,
-                    "display_text_field"   : property.type in (PROPERTY_TEXT_FIELD, PROPERTY_NUMBER_FIELD),
-                    "display_select_field" : property.type == PROPERTY_SELECT_FIELD,
-                    "value" : ppv_value,
+                    "id": property.id,
+                    "name": property.name,
+                    "title": property.title,
+                    "type": property.type,
+                    "options": options,
+                    "display_text_field": property.type in (PROPERTY_TEXT_FIELD, PROPERTY_NUMBER_FIELD),
+                    "display_select_field": property.type == PROPERTY_SELECT_FIELD,
+                    "value": ppv_value,
                 })
 
             configurables.append({
-                "id"   : property_group.id,
-                "name" : property_group.name,
-                "properties" : properties,
+                "id": property_group.id,
+                "name": property_group.name,
+                "properties": properties,
             })
 
+        # Filterable
         for property_group in product.property_groups.all():
             properties = []
             for property in property_group.properties.filter(filterable=True).order_by("groupspropertiesrelation"):
@@ -90,7 +94,7 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                 display_filterables = True
 
                 # Try to get the value, if it already exists.
-                ppvs = ProductPropertyValue.objects.filter(property = property, product=product, type=PROPERTY_VALUE_TYPE_FILTER)
+                ppvs = ProductPropertyValue.objects.filter(property=property, product=product, type=PROPERTY_VALUE_TYPE_FILTER)
                 value_ids = [ppv.value for ppv in ppvs]
 
                 # Mark selected options
@@ -103,27 +107,39 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                         selected = False
 
                     options.append({
-                        "id"       : option.id,
-                        "name"     : option.name,
-                        "selected" : selected,
+                        "id": option.id,
+                        "name": option.name,
+                        "selected": selected,
                     })
 
+                value = ""
+                if property.type == PROPERTY_SELECT_FIELD:
+                    display_select_field = True
+                else:
+                    display_select_field = False
+                    try:
+                        value = value_ids[0]
+                    except IndexError:
+                        pass
+
                 properties.append({
-                    "id" : property.id,
-                    "name" : property.name,
-                    "title" : property.title,
-                    "type" : property.type,
-                    "options" : options,
-                    "display_text_field"   : property.type in (PROPERTY_TEXT_FIELD, PROPERTY_NUMBER_FIELD),
-                    "display_select_field" : property.type == PROPERTY_SELECT_FIELD,
+                    "id": property.id,
+                    "name": property.name,
+                    "title": property.title,
+                    "type": property.type,
+                    "options": options,
+                    "value" : value,
+                    "display_text_field": not display_select_field,
+                    "display_select_field": display_select_field,
                 })
 
             filterables.append({
-                "id"   : property_group.id,
-                "name" : property_group.name,
-                "properties" : properties,
+                "id": property_group.id,
+                "name": property_group.name,
+                "properties": properties,
             })
 
+        # Displayable
         for property_group in product.property_groups.all():
             properties = []
             for property in property_group.properties.filter(display_on_product=True).order_by("groupspropertiesrelation"):
@@ -131,7 +147,7 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                 display_displayables = True
 
                 # Try to get the value, if it already exists.
-                ppvs = ProductPropertyValue.objects.filter(property = property, product=product, type=PROPERTY_VALUE_TYPE_DISPLAY)
+                ppvs = ProductPropertyValue.objects.filter(property=property, product=product, type=PROPERTY_VALUE_TYPE_DISPLAY)
                 value_ids = [ppv.value for ppv in ppvs]
 
                 # Mark selected options
@@ -144,25 +160,36 @@ def manage_properties(request, product_id, template_name="manage/product/propert
                         selected = False
 
                     options.append({
-                        "id"       : option.id,
-                        "name"     : option.name,
-                        "selected" : selected,
+                        "id": option.id,
+                        "name": option.name,
+                        "selected": selected,
                     })
 
+                value = ""
+                if property.type == PROPERTY_SELECT_FIELD:
+                    display_select_field = True
+                else:
+                    display_select_field = False
+                    try:
+                        value = value_ids[0]
+                    except IndexError:
+                        pass
+
                 properties.append({
-                    "id" : property.id,
-                    "name" : property.name,
-                    "title" : property.title,
-                    "type" : property.type,
-                    "options" : options,
-                    "display_text_field"   : property.type in (PROPERTY_TEXT_FIELD, PROPERTY_NUMBER_FIELD),
-                    "display_select_field" : property.type == PROPERTY_SELECT_FIELD,
+                    "id": property.id,
+                    "name": property.name,
+                    "title": property.title,
+                    "type": property.type,
+                    "options": options,
+                    "value" : value,
+                    "display_text_field": not display_select_field,
+                    "display_select_field": display_select_field,
                 })
 
             displayables.append({
-                "id"   : property_group.id,
-                "name" : property_group.name,
-                "properties" : properties,
+                "id": property_group.id,
+                "name": property_group.name,
+                "properties": properties,
             })
 
     # Generate list of all property groups; used for group selection
@@ -171,23 +198,25 @@ def manage_properties(request, product_id, template_name="manage/product/propert
     for property_group in PropertyGroup.objects.all():
 
         shop_property_groups.append({
-            "id" : property_group.id,
-            "name" : property_group.name,
-            "selected" : property_group.id in product_property_group_ids,
+            "id": property_group.id,
+            "name": property_group.name,
+            "selected": property_group.id in product_property_group_ids,
         })
 
     return render_to_string(template_name, RequestContext(request, {
-        "product" : product,
-        "filterables" : filterables,
-        "display_filterables" : display_filterables,
-        "configurables" : configurables,
-        "display_configurables" : display_configurables,
-        "displayables" : displayables,
-        "display_displayables" : display_displayables,
-        "product_property_groups" : product.property_groups.all(),
-        "shop_property_groups" : shop_property_groups,
+        "product": product,
+        "filterables": filterables,
+        "display_filterables": display_filterables,
+        "configurables": configurables,
+        "display_configurables": display_configurables,
+        "displayables": displayables,
+        "display_displayables": display_displayables,
+        "product_property_groups": product.property_groups.all(),
+        "shop_property_groups": shop_property_groups,
     }))
 
+
+@require_POST
 @permission_required("core.manage_shop", login_url="/login/")
 def update_property_groups(request, product_id):
     """Updates property groups for the product with passed id.
@@ -207,14 +236,17 @@ def update_property_groups(request, product_id):
             product = Product.objects.get(pk=product_id)
             product_removed_property_group.send([property_group, product])
 
-    url = reverse("lfs_manage_product", kwargs={"product_id" : product_id})
+    url = reverse("lfs_manage_product", kwargs={"product_id": product_id})
     return HttpResponseRedirect(url)
 
+
+@require_POST
 @permission_required("core.manage_shop", login_url="/login/")
 def update_properties(request, product_id):
     """Updates properties for product with passed id.
     """
     type = request.POST.get("type")
+    ProductPropertyValue.objects.filter(product=product_id, type=type).delete()
 
     # Update property values
     for key in request.POST.keys():
@@ -225,11 +257,9 @@ def update_properties(request, product_id):
         property = get_object_or_404(Property, pk=property_id)
         product = get_object_or_404(Product, pk=product_id)
 
-        ProductPropertyValue.objects.filter(product = product_id, property = property_id, type=type).delete()
-
         for value in request.POST.getlist(key):
             if property.is_valid_value(value):
-                ProductPropertyValue.objects.create(product=product, property = property, value=value, type=type)
+                ProductPropertyValue.objects.create(product=product, property=property, value=value, type=type)
 
-    url = reverse("lfs_manage_product", kwargs={"product_id" : product_id})
+    url = reverse("lfs_manage_product", kwargs={"product_id": product_id})
     return HttpResponseRedirect(url)
